==> lxqt-panel-2.0.0.tar.xz: lxqt-panel-2.0.0/plugin-desktopswitch/translations/desktopswitch_pa.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pa">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="88"/>
        <source>Switch to desktop %1</source>
        <translation>%1 ਡੈਸਕਟਾਪ ਉੱਤੇ ਜਾਓ</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="149"/>
        <location filename="../desktopswitch.cpp" line="160"/>
        <source>Desktop %1</source>
        <translation>ਡੈਸਕਟਾਪ %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation>ਡੈਸਕਟਾਪ-ਸਵਿੱਚ ਸੈਟਿੰਗਾਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>ਕਤਾਰਾਂ ਦੀ ਗਿਣਤੀ:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>ਡੈਸਕਟਾਪ ਲੇਬਲ:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>ਦਿੱਖ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>ਅੰਕ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>ਨਾਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>ਕੋਈ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>ਜੇ ਚੁਣਿਆ ਤਾਂ ਵਿਜੈੱਟ ਸਿਰਫ਼ ਸੰਕੇਤ ਹੋਵੇਗਾ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>ਸਿਰਫ਼ ਸਰਗਰਮ ਡੈਸਕਟਾਪ ਉੱਤੇ ਹੀ ਵੇਕਾਓ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>ਡੈਸਕਟਾਪਾਂ ਦੇ ਨਾਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="71"/>
        <source>Desktop %1:</source>
        <translation>ਡੈਸਕਟਾਪ %1:</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchUnsupported</name>
    <message>
        <location filename="../desktopswitch.h" line="111"/>
        <source>n/a</source>
        <translation>ਲਾਗੂ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitch.h" line="113"/>
        <source>DesktopSwitch is unsupported on current platform: %1</source>
        <translation>ਡੈਸਕਟਾਪ-ਸਵਿੱਚ ਮੌਜੂਦਾ ਪਲੇਟਫਾਰਮ ਲਈ ਸਹਾਇਕ ਨਹੀਂ ਹੈ: %1</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-desktopswitch/translations/desktopswitch_pa.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pa">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="95"/>
        <source>Switch to desktop %1</source>
        <translation>%1 ਡੈਸਕਟਾਪ ਉੱਤੇ ਜਾਓ</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="170"/>
        <location filename="../desktopswitch.cpp" line="181"/>
        <source>Desktop %1</source>
        <translation>ਡੈਸਕਟਾਪ %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch Settings</source>
        <translation>ਡੈਸਕਟਾਪ-ਸਵਿੱਚ ਸੈਟਿੰਗਾਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>ਕਤਾਰਾਂ ਦੀ ਗਿਣਤੀ:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>ਡੈਸਕਟਾਪ ਲੇਬਲ:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>ਦਿੱਖ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>ਅੰਕ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>ਨਾਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>ਕੋਈ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>ਜੇ ਚੁਣਿਆ ਤਾਂ ਵਿਜੈੱਟ ਸਿਰਫ਼ ਸੰਕੇਤ ਹੋਵੇਗਾ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>ਸਿਰਫ਼ ਸਰਗਰਮ ਡੈਸਕਟਾਪ ਉੱਤੇ ਹੀ ਵੇਕਾਓ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>ਡੈਸਕਟਾਪਾਂ ਦੇ ਨਾਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="78"/>
        <source>Desktop %1:</source>
        <translation>ਡੈਸਕਟਾਪ %1:</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchUnsupported</name>
    <message>
        <location filename="../desktopswitch.cpp" line="342"/>
        <source>n/a</source>
        <translation>ਲਾਗੂ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="344"/>
        <source>DesktopSwitch is unsupported on current platform: %1</source>
        <translation>ਡੈਸਕਟਾਪ-ਸਵਿੱਚ ਮੌਜੂਦਾ ਪਲੇਟਫਾਰਮ ਲਈ ਸਹਾਇਕ ਨਹੀਂ ਹੈ: %1</translation>
    </message>
</context>
</TS>
